rnalysis.filtering.DESeqFilter
==============================

.. currentmodule:: rnalysis.filtering

.. autoclass:: DESeqFilter

   
   
   
    .. automethod:: __init__
    
    

   
.. autosummary::
    :toctree: .
    
    DESeqFilter.biotypes
    DESeqFilter.describe
    DESeqFilter.difference
    DESeqFilter.filter_abs_log2_fold_change
    DESeqFilter.filter_biotype
    DESeqFilter.filter_by_attribute
    DESeqFilter.filter_fold_change_direction
    DESeqFilter.filter_percentile
    DESeqFilter.filter_significant
    DESeqFilter.filter_top_n
    DESeqFilter.head
    DESeqFilter.intersection
    DESeqFilter.number_filters
    DESeqFilter.print_features
    DESeqFilter.save_csv
    DESeqFilter.sort
    DESeqFilter.split_by_attribute
    DESeqFilter.split_by_percentile
    DESeqFilter.split_fold_change_direction
    DESeqFilter.symmetric_difference
    DESeqFilter.tail
    DESeqFilter.text_filters
    DESeqFilter.union
    DESeqFilter.volcano_plot
    
    